<?php
/*
 * films.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	films.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://x-tnd.be
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

/**
 * Collections management
 *
 * @package    Vidéothèque
 * @author     Johan Cwiklinski <johan AT x-tnd DOT be>
 * @version    0.1
 * @link       http://videotheque.tuxfamily.org
 */

class Collections{
	private $id;
	private $nom;
	private $table;
	private $prive;

	private $compte;
	private $requete;

	const TABLE = _collections;
	const PK = 'id_collection';
	
	/**
	* Default constructor
	*/
	function __construct(){}

	/**
	* Charge la liste des collections
	* @return tableau
	*/
	public function getList(){
		global $varspages, $login, $db;

		$requete = 'SELECT * FROM ' . self::TABLE;
		if(!$login->isAuth()) $requete.= ' WHERE prive=0';
		$requete .= ' ORDER BY nom ASC';
		$this->requete = $requete;

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->compte = $result->numRows();

		$collections = $result->fetchAll();
		$array = array();
		foreach($collections as $col){
			/** TODO
			* Use XML to transfer lists, with an XSL transofrmation
			*/
			$subarray = array();
			foreach($col as $key=>$value){
				$subarray[$key] = $value;
			}
			$array[] = $subarray;
		}
		return $array;
	}

	/**
	* Charge la collection en paramètre
	* @param id identifiant de l'enregistrement à charger
	*/
	public function load($id){
		global $db;
		$requete = 'SELECT * FROM ' . self::TABLE . ' WHERE ' . self::PK . '=' . $id;

		if( !$result = $db->query( $requete ) )
			return -1;

		if( $result->numRows() == 1){
			$collection = $result->fetchRow();
			$id = self::PK;
			$this->id = $collection->$id;
			$this->nom = $collection->nom;
			$this->table = $collection->table;
			$this->prive = $collection->prive;
 		}
	}

	/**
	* Charge le nom de la collection en paramètre
	* @param id identifiant du nom à charger
	*/
	public function loadName($id){
		global $db;
		$requete = 'SELECT nom FROM ' . self::TABLE . ' WHERE ' . self::PK . '=' . $id;

		if( !$result = $db->query( $requete ) )
			return -1;

		return $result->fetchOne('nom');
	}

	/**
	* Builds queries commons parts for register and update.
	* @return query string without STATEMENT nor WHERE clause
	*/
	private function buildQueries(){
		$requete = 'nom=\'' . $this->nom . '\', ';
		//We must specify table name since 'table' is reserved in mysql
		$requete .= self::TABLE . '.table=\'' . $this->table . '\', ';
		$requete .= 'prive=\'' . ((isset($this->prive))?$this->prive:0) . '\'';
		return $requete;
	}

	/**
	* Updates collection details to database.
	* @param id collection's id
	* @returns state only '-1' if there were a database problem
	*/
	public function update($id){
		global $db;
		$requete = 'UPDATE ' . self::TABLE . ' SET ';
		$requete .= $this->buildQueries();
		$requete .= ' WHERE ' . self::PK . '=' . $id;

		if( !$result = $db->query( $requete ) )
			return -1;
		return 1;
	}


	/* GETTERS */
	public function getCompte(){return $this->compte;}
	public function getQuery(){return $this->requete;}
	public function getId(){return $this->id;}
	public function getName(){return $this->nom;}
	public function getTable(){return $this->table;}
	public function isPrive(){return ($this->prive==1)?true:false;}

	/* SETTERS */
	public function setName($name){$this->nom = $name;}
	public function setTable($table){$this->table = $table;}
	public function setPrive($prive){$this->prive = $prive;}
}
?>