<?php
/*
 * films.class.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	films.class.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://videotheque.tuxfamily.org
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

require_once('genres.class.php');
require_once('origines.class.php');
require_once('realisateurs.class.php');
require_once('acteurs.class.php');
require_once('collections.class.php');

class Films{
	private $id;
	private $titre;
	private $sous_titre;
	private $annee;
	private $resume;
	private $duree;
	private $cd;

	private $genres = array();
	private $realisateurs = array();
	private $origines = array();
	private $acteurs = array();
	private $collection;

	private $compte;
	private $requete;

	const PK = 'id_film';
	
	function __construct(){
		global $varspages;
		$this->collection = new Collections();
		$this->collection->load($varspages->getCollection());
	}

	private function prepareSelect($search){
		global $varspages;

		$table = _tblPrefix.$this->collection->getTable();
		$types_movies = _tblPrefix.$this->collection->getTable()._types;
		$directors_movies = _tblPrefix.$this->collection->getTable()._directors;
		$origins_movies = _tblPrefix.$this->collection->getTable()._origins;
		$actors_movies = _tblPrefix.$this->collection->getTable()._actors;

		$requete = 'SELECT ' . $table . '.' . self::PK . ' as Num, titre As Titre, sous_titre As Sous_Titre, ';
		//Types
		$requete .= _types . '.genre As Genre, cd As CD FROM ' . $table;
		$requete .= ' INNER JOIN ' . $types_movies . ' USING(' . self::PK . ')';
		$requete .= ' INNER JOIN ' . Genres::TABLE . ' USING(' . Genres::PK . ')';
		//Directors
		$requete .= ' INNER JOIN ' . $directors_movies . ' USING(' . self::PK . ')';
		$requete .= ' INNER JOIN ' . Realisateurs::TABLE . ' USING(' . Realisateurs::PK . ')';
		//Origins
		$requete .= ' INNER JOIN ' . $origins_movies . ' USING(' . self::PK . ')';
		$requete .= ' INNER JOIN ' . Origines::TABLE . ' USING(' . Origines::PK . ')';
		//Actors
		$requete .= ' LEFT JOIN ' . $actors_movies . ' USING(' . self::PK . ')';
		$requete .= ' LEFT JOIN ' . Acteurs::TABLE . ' USING(' . Acteurs::PK . ')';
		if($search)//where clause
			$requete .= $this->buildWhere();
		$requete .= ' GROUP BY ' . $table . '.' . self::PK;
		$orderby = ($varspages->getOrder() == 'id_film')?$table . '.' . $varspages->getOrder():$varspages->getOrder();
		$requete .= ' ORDER BY ' . $orderby . ' ' . $varspages->getDirection();

		return $requete;
	}

	public function getList($collection=false, $search=true){
		global $varspages, $db;

		if($collection) $this->collection->load($collection);

		$requete = $this->prepareSelect($search);

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->compte = $result->numRows();

		$requete .= $this->getLimits();
		$this->requete = $requete;

		if( !$result = $db->query( $requete ) )
			return -1;

		$films = $result->fetchAll();
		$array = array();
		foreach($films as $film){
			$subarray = array();
			foreach($film as $key=>$value){
				/** FIXME: find a portable alternative to catch database encoding */
				$subarray[$key] = (mysql_client_encoding() == 'latin1')?utf8_encode($value):$value;
			}
			$array[] = $subarray;
		}

		return $array;
	}

	public function getXmlList($collection=false){
		global $varspages, $db;

		if($collection) $this->collection->load($collection);

		$xml = "<?xml version='1.0' encoding='UTF-8' ?>\r";
		$xml .= '<films';
 		if($collection) $xml .= ' collection="' . $this->collection->getName() . '"';
		$xml .= ">\r";

		$requete = $this->prepareSelect();

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->compte = $result->numRows();

		$requete .= $this->getLimits();
		$this->requete = $requete;

		if( !$result = $db->query( $requete ) )
			return -1;


		$films = $result->fetchAll();
		foreach($films as $film){
			$xml .= "\t<film>\n";
			foreach($film as $key=>$value){
				/** FIXME: find a portable alternative to catch database encoding */
				if(mysql_client_encoding() == 'latin1') $value = utf8_encode($value);
				$patterns = array('/&/', '/</', '/>/');
				$replacements = array('&amp;', '&lt;', '&gt;');
				$value = preg_replace($patterns, $replacements, $value);
				$xml .= "\t\t<".$key.">".$value."</".$key.">\n";
			}
			$xml .= "\t</film>\n";
		}

		$xml .= '</films>';

		return $xml;
	}

	private function buildWhere(){
		global $varspages, $db;
		$where = "";
		$queryWhere = array();

		//Types
		if(is_array($varspages->getGenre()) && !in_array('all', $varspages->getGenre())){
			$queryWhere[] = _types . '.' . Genres::FIELD . '=\'' . implode('\' OR ' . _types . '.' . Genres::FIELD . '=\'', $varspages->getGenre()) . '\'';
		}elseif(trim($varspages->getGenre())!='' && $varspages->getGenre() != 'all'){
			$queryWhere[] = _types . '.' . Genres::PK . '=\'' . $varspages->getGenre() . '\'';
		}

		//Directors
		if(is_array($varspages->getDirector()) && !in_array('all', $varspages->getDirector())){
			$queryWhere[] = _directors . '.' . Realisateurs::FIELD . '=\'' . implode('\' OR ' . _directors . '.' . Realisateurs::FIELD . '=\'', $varspages->getDirector()) . '\'';
		}elseif(trim($varspages->getDirector())!='' && $varspages->getDirector() != 'all'){
			$queryWhere[] = _directors . '.'. Realisateurs::PK . '=\'' . $varspages->getDirector() . '\'';
		}

		//Origins
		if(is_array($varspages->getOrigin()) && !in_array('all', $varspages->getOrigin())){
			$queryWhere[] = _origins . '.' . Origines::FIELD . '=\'' . implode('\' OR ' . _origins . '.' . Origines::FIELD . '=\'', $varspages->getOrigin()) . '\'';
		}elseif(trim($varspages->getOrigin())!='' && $varspages->getOrigin() != 'all'){
			$queryWhere[] = _origins . '.'. Origines::PK . '=\'' . $varspages->getOrigin() . '\'';
		}

		//Actors
		if(is_array($varspages->getActor()) && !in_array('all', $varspages->getActor())){
			$queryWhere[] = _actors . '.' . Acteurs::FIELD . '=\'' . implode('\' OR ' . _actors . '.' . Acteurs::FIELD . '=\'', $varspages->getActor()) . '\'';
		}elseif(trim($varspages->getActor())!='' && $varspages->getActor() != 'all'){
			$queryWhere[] = _actors . '.'. Acteurs::PK . '=\'' . $varspages->getActor() . '\'';
		}

		//Year
		if($varspages->year != null){
			if( $varspages->year['from'] != null && $varspages->year['to'] != null ){
				$queryWhere[] = ' annee BETWEEN ' . $varspages->year['from'] . ' AND ' . $varspages->year['to'];
			}elseif( $varspages->year['from'] != null && $varspages->year['to'] == null ){
				$queryWhere[] = ' annee > ' . $varspages->year['from'];
			}elseif( $varspages->year['from'] == null && $varspages->year['to'] != null ){
				$queryWhere[] = ' annee < ' . $varspages->year['to'];
			}
		}

		//Duration
		if($varspages->duration != null){
			if( $varspages->duration['from'] != null && $varspages->duration['to'] != null ){
				$queryWhere[] = ' duree BETWEEN ' . $varspages->duration['from'] . ' AND ' . $varspages->duration['to'];
			}elseif( $varspages->duration['from'] != null && $varspages->duration['to'] == null ){
				$queryWhere[] = ' duree >= ' . $varspages->duration['from'];
			}elseif( $varspages->duration['from'] == null && $varspages->duration['to'] != null ){
				$queryWhere[] = ' duree <= ' . $varspages->duration['to'];
			}
		}

		//Title and subtitle
		if(trim($varspages->getTitle())!=''){
			$title = (mysql_client_encoding() == 'latin1') ? utf8_decode($varspages->getTitle()) : $varspages->getTitle();
			//we supress quotes at beginning and end of the string since we use % for title search
			$title = trim($db->getDb()->quote($title), '\'');
			$queryWhere[] = '(titre LIKE \'%' . $title . '%\' OR sous_titre LIKE \'%' . $title . '%\')';
		}
	
		for($i=0;$i<count($queryWhere);$i++){
			$where .= ($i == 0)?' WHERE ':' AND ';
			$where .= $queryWhere[$i];
		}

		return $where;
	}

	private function getLimits(){
		global $varspages;
		$limitinf = (($varspages->getPage()-1)>0)?($varspages->getPage()-1)*$varspages->getRange():0;
		return ($varspages->getRange() == 'all')?'':' LIMIT ' . $limitinf . ',' . $varspages->getRange();
	}

	public function loadMovie($id){
		global $db;
		$this->id = $id;
		$requete = 'SELECT * FROM ';
		$requete .= $this->collection->getTable();
		$requete .= ' WHERE ' . self::PK . '=' . $id;

		if( !$result = $db->query( $requete ) )
			return -1;

		$row = $result->fetchRow();

		$this->titre = (mysql_client_encoding() == 'latin1')?utf8_encode($row->titre):$row->titre;
		$this->sous_titre = (mysql_client_encoding() == 'latin1')?utf8_encode($row->sous_titre):$row->sous_titre;
		$this->annee = $row->annee;
		$this->resume = (mysql_client_encoding() == 'latin1')?utf8_encode($row->resume):$row->resume;
		$this->duree = $row->duree;
		$this->cd = $row->cd;

		$g = new Genres();
		$this->genres = $g->getMovieTypes($this->id);

		$o = new Origines();
		$this->origines = $o->getMovieOrigins($this->id);

		$r = new Realisateurs();
		$this->realisateurs = $r->getMovieDirectors($this->id);

		$a = new Acteurs();
		$this->acteurs = $a->getMovieActors($this->id);
	}

	/**
	* Retrive movies that match a title or a subtitle
	* @param string string to search into titles and subtitles
	* @return mdb2 results object
	*/
	public static function getTitles($string){
		global $varspages, $db;
		$collection = new Collections();
		$collection->load($varspages->getCollection());

		$requete = 'SELECT titre, sous_titre, annee FROM ';
		$requete .= $collection->getTable();
		$requete .= ' WHERE (titre LIKE \'%' . $string . '%\' OR sous_titre LIKE \'%' . $string . '%\')';

		if( !$result = $db->query( $requete ) )
			return -1;

		return $result->fetchAll();
	}

	/* GETTERS */
	public function getCompte(){return $this->compte;}
	public function getQuery(){return $this->requete;}
	public function getId(){return $this->id;}
	public function getTitre(){return $this->titre;}
	public function getSousTitre(){return $this->sous_titre;}
	public function getAnnee(){return $this->annee;}
	public function getResume(){return $this->resume;}
	public function getDuree(){return $this->duree;}
	public function getCd(){return $this->cd;}
	public function getGenres(){return $this->genres;}
	public function getRealisateurs(){return $this->realisateurs;}
	public function getOrigines(){return $this->origines;}
	public function getActeurs(){return $this->acteurs;}

	/* SETTERS */
	public function setCollection($collection){
		if(get_class($collection) != 'Collections'){
			global $preferences;
			$this->collection = new Collections();
			$this->collection->load($preferences->getDefaultCollection());
		}else $this->collection = $collection;
	}
}
?>