<?php
/*
 * genres.class.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	genres.class.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://x-tnd.be
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

require_once('collections.class.php');

/**
 * Abstract class for 'strong' relations
 *
 * Should be inherit from :
 * 	- actors class
 *	- directors class
 * 	- types class
 * 	- origins class
 *
 * @package    Vidéothèque
 * @author     Johan Cwiklinski <johan AT x-tnd DOT be>
 * @version    0.1
 * @link       http://videotheque.tuxfamily.org
 * @abstract
 */
abstract class Join{
	protected $id;
	protected $valeur;
	protected $collection;

	private $table;
	private $rtable;
	private $primary;
	private $field;

	/**
	* Constructeur
	*/
	function __construct($table, $rtable, $primary, $field){
		global $varspages;
		$this->collection = new Collections();
		$this->collection->load($varspages->getCollection());
		$this->table = (_tblPrefix != '')?_tblPrefix . $table:$table;
		$this->rtable = (_tblPrefix != '')?_tblPrefix . $rtable:$rtable;
		$this->primary = $primary;
		$this->field = $field;
	}

	/**
	* Charge un type joint
	* @param id identifiant de l'enregistrement à charger
	*/
	public function load($id){
		global $db;
		$requete = 'SELECT * FROM ' . ($this->collection->isPrive()?$this->rtable:$this->table) . ' WHERE ' . $this->primary . '=' . $id;

		if( !$result = $db->query( $requete ) )
			return -1;

		$list = $result->fetchRow();

		$this->id = $list->{$this->primary};
		$this->valeur = $list->{$this->field};
	}

	/**
	* Liste du type joint
	* @return tableau de liste des acteurs
	*/
	public function getList(){
		global $db;
		$requete = 'SELECT * FROM ' . ($this->collection->isPrive()?$this->rtable:$this->table) . ' ORDER BY ' . $this->field;

		if( !$result = $db->query( $requete ) )
			return -1;

		$list = $result->fetchAll();
		$array = array();
		foreach($list as $l){
			$array[] = array(
				"id"	=>	$l->{$this->primary},
				$this->field	=>	(mysql_client_encoding()=="latin1")?utf8_encode($l->{$this->field}):$l->{$this->field}
			);
		}
		return $array;
	}

	/**
	* Renvoie les noms des types joints
	* @param ids tableau des identifiants des types joints à charger
	* @return tableau des noms des acteurs
	*/
	public function getNames($ids){
		global $db;

		$requete = 'SELECT '. $this->field .' FROM ' . ($this->collection->isPrive?$this->rtable:$this->table);
		$requete .= ' WHERE ' . $this->primary . '=';
		if(is_array($ids))
			$requete .= implode(' OR ' . $this->primary . '=', $ids);
		else
			$requete .= $ids;

		if( !$result = $db->query( $requete ) )
			return -1;

		$list = $result->fetchAll();
		$array = array();
		foreach($list as $l){
			$array[] = (mysql_client_encoding()=="latin1")?utf8_encode($l->{$this->field}):$l->$this->field;
		}
		return $array;
	}

 	/**
	* Charge les types joints d'une vidéo
	* @param id_movie identifiant de la vidéo
	* @return tableau des types joints
	*/
	public function getTypeFromMovie($id_movie){
		global $db;
		$relation = _tblPrefix.$this->collection->getTable().$this->table;
		$requete = 'SELECT * FROM ' . ($this->collection->isPrive()?$this->rtable:$this->table) . ' INNER JOIN ' . $relation . ' USING(' . $this->primary . ')';
		$requete .= ' WHERE id_film=' . $id_movie;

		if( !$result = $db->query( $requete ) )
			return -1;

		$actors = $result->fetchAll();
		$array = array();
		foreach($actors as $act){
			$array[] = array(
				"id"	=>	$act->{$this->primary},
				$this->field	=>	(mysql_client_encoding()=="latin1")?utf8_encode($act->{$this->field}):$act->{$this->field}
			);
		}
		return $array;
	}

	/**
	* Récupère les films du type joint
	* @return tableau des films
	*/
	public function getJoinedResults(){
		global $db;
		$relation = _tblPrefix.$this->collection->getTable()._types;
		$relationg = _tblPrefix.$this->collection->getTable() . (($this->table==_types)?_actors:$this->table);
		$requete = 'SELECT distinct(' . Films::PK . '), titre, sous_titre, genre FROM ' . $this->collection->getTable();
		$requete .= ' LEFT JOIN ' . $relation . ' USING(' . Films::PK . ') INNER JOIN ' . ($this->collection->isPrive()?Genres::RTABLE:Genres::TABLE) . ' USING(' . Genres::PK . ')';
		$requete .= ' INNER JOIN ' . $relationg . ' USING(' . Films::PK . ') WHERE ' . $this->primary . '=' . $this->id;
		$requete .= ' ORDER BY titre, sous_titre ASC';

		if( !$result = $db->query( $requete ) )
			return -1;

		$joined_results = $result->fetchAll();
		$array = array();
		foreach($joined_results as $res){
			$subarray = array();
			foreach($res as $key=>$value){
				if(mysql_client_encoding()=="latin1") $value = utf8_encode($value);
				$subarray[$key] = $value;
			}
			$array[] = $subarray;
		}
		return $array;
	}

	/**
	* Retrieve object from a textual search on its value 
	* @param string string to search
	* @return mdb2 results object
	*/
	public function getObject($string){
		global $db;

		$requete = 'SELECT ' . $this->field . ' FROM ' . ($this->collection->isPrive()?$this->rtable:$this->table);
		$requete .= ' WHERE (' . $this->field . ' LIKE \'%' . $string . '%\')';

		if( !$result = $db->query( $requete ) )
			return -1;

		return $result->fetchAll();
	}

}
?>