<?php
/*
 * reservation.class.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	reservation.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://x-tnd.be
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

require_once('films.class.php');
require_once('users.class.php');
require_once('collections.class.php');

/**
 * Movie resrevation
 *
 * @package    Vidéothèque
 * @author     Johan Cwiklinski <johan AT x-tnd DOT be>
 * @version    0.1
 * @link       http://videotheque.tuxfamily.org
 */
class Reservation{
	private $liste = array();
	private $compte;

	const TABLE = _reservations;

	/**
	* Default constructor
	*/
	function __construct(){
		$this->liste = $this->liste();
	}

	/**
	* Add a new reservation
	* @param value movie's id to store
	* @returns state :
	*	- '-1' if there were a database problem
	*	- 1 if all goes well
	*/
	public function add($value){
		global $login, $varspages, $db;

		$date = date("Y-m-d H:i:s");
		$requete = 'INSERT IGNORE INTO ' . self::TABLE . ' (login, id_film, collection, date) VALUES (\'' . $login->getLogin() . '\', ' . $value . ', ' . $varspages->getCollection() . ', \'' . $date . '\')';

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->liste = $this->liste();
		return 1;
	}

	/**
	* Check if the value is stored
	* @param needle value to search
	* @param haystack the array in which we search
	*/
	private function in_arrayr($needle, $haystack) {
		foreach ($haystack as $v) {
			if ($needle == $v['num']) return true;
		}
		return false;
	}

	/**
	* Check if the movie is in reservations' array
	* @param value the movie id
	* @return true if the movie is reserved, false otherwise
	*/
	public function isReserved($value){
		if(!is_array($this->liste)) return false;
		return $this->in_arrayr($value, $this->liste);
	}

	/**
	* Build the query
	* @param table name of the collection's table
	* @param types_tables type's table associated
	* @param types_movies movies to types relation table
	* @param where where clause to apply
	* @param stored are we working on an already stored record ?
	*/
	private function getQuery($table, $types_table, $types_movies, $where, $stored=true){
		$requete = 'SELECT ' . $table . '.' . Films::PK . ' as Num, titre As Titre, sous_titre As Sous_Titre, ';
		$requete .= $types_table . '.genre As Genre, cd As CD FROM ';
		$requete .= ($stored)?self::TABLE:$table;
		$requete .= ($stored)?' INNER JOIN ' . $table . ' ON(' . self::TABLE . '.' . Films::PK . '=' . $table . '.' . Films::PK . ')':'';
		$requete .= ' INNER JOIN ' . $types_movies . ' ON(' . $table . '.' . Films::PK . '=' . $types_movies . '.' . Films::PK . ')';
		$requete .= ' INNER JOIN ' . $types_table . ' ON(' . $types_movies . '.id_genre=' . $types_table . '.id_genre)';
		$requete .= ' WHERE ' . $where;
		$requete .= ' GROUP BY ' . $table . '.' . Films::PK;
		return $requete;
	}

	/**
	* Lists reservations for a user
	* @param user user's login to load. If not specified, we take the logged one.
	* @returns
	*	- '-1' if there were a database problem
	*	- array of the reservations otherwise
	*/
	function liste($user = 'default'){
		global $collections, $db;
		if($user == 'default'){
			global $login;
		}else{
			$login = new Users();
			$login->load($user);
		}
		$array = array();

		$where = 'login=\'' . $login->getLogin() . '\' AND collection=' . $collections->getId();
		$requete = $this->getQuery(
			$collections->getTable(),
			($collections->isPrive()?_rtypes:_types),
			$collections->getTable()._types,
			$where
		);

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->compte = $result->numRows();

		$list = $result->fetchAll();
		$array = array();
		foreach($list as $l){
			$subarray = array();
			foreach ($l as $key=>$value) {
				if(mysql_client_encoding() == 'latin1') $value = utf8_encode($value);
				$subarray[$key] = $value;
			}
			$array[] = $subarray;
		}

		return $array;
	}


	/**
	* Lists reservations for a user, in xml format
	* @param user user's login to load. If not specified, we take the logged one.
	* @param allCollections false to list the current selected collection, true to list all collections in database
	* @returns
	*	- '-1' if there were a database problem
	*	- xml list of the reservations otherwise
	*/
	function listeXml($user = 'default', $allCollections = false){
		global $collections;
		if($user == 'default'){
			global $login;
		}else{
			$login = new Users();
			$login->load($user);
		}

		$xml = "<?xml version='1.0' encoding='UTF-8' ?>\r";
		$xml .= "<reservations user=\"" . $login->getLogin() . "\">\r";

		if($allCollections == false){
			$xml .= $this->getReservations($login, $collections);
		}else{
			foreach($collections->getList() as $c){
				$col = new Collections();
				$col->load($c[Collections::PK]);
				$xml .= $this->getReservations($login, $col);
			}
		}

		$xml .= '</reservations>';

		return $xml;
	}

	/**
	* Build XML of reservations for a specified collection and user
	* @param login user to retrieve reservations
	* @param collections collection to retrieve
	* @returns reservations for specified user and collection
	*/
	private function getReservations($login, $collections){
		global $db;
		$where = 'login=\'' . $login->getLogin() . '\' AND collection=' . $collections->getId();
		$requete = $this->getQuery(
			$collections->getTable(),
			($collections->isPrive()?_rtypes:_types),
			$collections->getTable()._types,
			$where
		);

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->compte = $result->numRows();

		$xml = "\t<collection id=\"".$collections->getId()."\" name=\"".$collections->getName()."\">\n";

		$list = $result->fetchAll();
		foreach($list as $l){
			$xml .= " \t\t<reservation>\n";
			foreach ($l as $key=>$value) {
				if(mysql_client_encoding() == 'latin1') $value = utf8_encode($value);
				$patterns = array('/&/', '/</', '/>/');
				$replacements = array('&amp;', '&lt;', '&gt;');
				$value = preg_replace($patterns, $replacements, $value);
				$xml .= "\t\t\t<" . $key . ">" . $value . "</" . $key . ">\n";
			}
			$xml .= " \t\t</reservation>\n";
		}
		$xml .= "\t</collection>\n";

		return $xml;
	}

	/**
	* Deletes a reservation
	* @param id id of the movie
	* @param collection collection to work on. If not specified, we take the current navigation value.
	* @returns state
	*	- '-1' if there were a database problem
	*	- 1 if all goes well
	*/
	public function deletes($id, $user = false, $collection = 'default'){
		global $db;
		if(!$user){
			global $login;
		}else{
			$login = new Users();
			$login->load($user);
		}

		if($collection == 'default'){
			global $varspages;
			$collection = $varspages->getCollection();
		}

		$requete = 'DELETE FROM ' . self::TABLE . ' WHERE login=\'' . $login->getLogin() . '\' AND id_film=' . $id . ' AND collection=' . $collection;

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->liste = $this->liste();
		return 1;
	}

	/**
	* Deletes all reservations for current user.
	*/
	public function deletesAll(){
		global $login;
		$requete = 'DELETE FROM ' . self::TABLE . ' WHERE login=\'' . $login->getLogin() . '\'';

		if( !$result = $db->query( $requete ) )
			return -1;

		$this->liste = array();
		return; 
	}

	/* GETTERS */
	public function getCompte(){return $this->compte;}
}
?>