<?php
/*
 * varspage.class.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	varspage.class.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://videotheque.tuxfamily.org
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

/**
 * Navigation parameters
 *
 * @package    Vidéothèque
 * @author     Johan Cwiklinski <johan AT x-tnd DOT be>
 * @version    0.1
 * @link       http://videotheque.tuxfamily.org
 */
class Varspage{
	private $pageencours;
	private $enrsbypage;
	private $orderby;
	private $mode;
	private $ordered;
	private $type;
	private $types_operator;
	private $director;
	private $directors_operator;
	private $origin;
	private $origins_operator;
	private $actor;
	private $actors_operator;
	private $quicktitle;
	private $file = 'varspage.xml';
	private $collection;
	private $searchmode;
	private $year;
	private $duration;

	const RESERV_MODE = 'reserv';
	const CONSULT_MODE = 'consult';

	const ORDER_ASC = 'ASC';
	const ORDER_DESC = 'DESC';
	
	/**
	* Default constructor
	*/
	public function __construct(){
		$this->file = _baseConfig.$this->file;
		$this->loadFromXml();
	}

	/**
	* Reinit default parameters from the XML file
	*/
	public function reinit(){
		$this->loadFromXml();
		$this->type = NULL;
		$this->director = NULL;
		$this->origin = NULL;
		$this->actor = NULL;
		$this->quicktitle = NULL;
		$this->year = NULL;
		$this->duration = NULL;
	}

	/**
	* Loads the default values from the xml file
	*/
	private function loadFromXml(){
		$varspagexml = simplexml_load_file($this->file);
		$this->pageencours = (string)$varspagexml->pageencours;
		$this->enrsbypage = (string)$varspagexml->enrsbypage;
		$this->orderby = (string)$varspagexml->orderby;
		$this->mode = (string)$varspagexml->mode;
		$this->ordered = (string)$varspagexml->ordered;
		$this->collection = (int)$varspagexml->collection;
		$this->searchmode = (string)$varspagexml->searchmode;
		// Set default operators for advanced search
		$this->types_operator = (string)$varspagexml->types_operator;
		$this->directors_operator = (string)$varspagexml->directors_operator;
		$this->origins_operator = (string)$varspagexml->origins_operator;
		$this->actors_operator = (string)$varspagexml->actors_operator;
	}

	/**
	* Reinit settings for search and change collection
	* This method only reinit current page number and sort order
	*/
	public function searchInit(){
		$varspagexml=simplexml_load_file($this->file);
		$this->pageencours = (string)$varspagexml->pageencours;
		$this->orderby=(string)$varspagexml->orderby;
	}

	/**
	* Change one of the parameters
	* @param name parameter's name
	* @param value parameter's value to set
	* @deprecated use __set or specific setter
	*/
	public function modifvalue($name, $value){
		$this->$name = $value;
	}

	/**
	* Changes the sort order
	*/
	public function invertorder(){
		$actual=$this->ordered;
		if($actual == self::ORDER_ASC){
			$this->ordered = self::ORDER_DESC;
		}
		if($actual == self::ORDER_DESC){
			$this->ordered = self::ORDER_ASC;
		}
	}

	/* GETTERS */
	public function getPage(){return $this->pageencours;}
	public function getRange(){return $this->enrsbypage;}
	public function getOrder(){return $this->orderby;}
	public function getMode(){return $this->mode;}
	public function getDirection(){return $this->ordered;}
	/** @deprecated : use __get instead */
	public function getGenre(){return $this->type;}
	/** @deprecated : use __get instead */
	public function getDirector(){return $this->director;}
	/** @deprecated : use __get instead */
	public function getOrigin(){return $this->origin;}
	/** @deprecated : use __get instead */
	public function getActor(){return $this->actor;}
	public function getTitle(){return $this->quicktitle;}
	public function getCollection(){return $this->collection;}
	public function getSearchMode(){return $this->searchmode;}

	public function __get($name){
		global $log;
		$return_ok = array(
			'type',
			'director',
			'origin',
			'actor',
			'year',
			'duration',
			'types_operator',
			'directors_operator',
			'origins_operator',
			'actors_operator',
		);
		if(in_array($name, $return_ok))
			return $this->$name;
		else
			$log->log('[varspage.class.php] Unable to get proprety `' . $name . '`', PEAR_LOG_WARNING);
	}

	/* SETTERS */
	public function setTitle($title){$this->quicktitle = $title;}
	public function setCollection($collection){
		if($collection==-1){
			$varspagexml = simplexml_load_file($this->file);
			$this->collection = (int)$varspagexml->collection;
		}else $this->collection = $collection;
	}
	public function setSearchMode($mode){$this->searchmode = $mode;}

	public function __set($name, $value){
		global $log;

		switch($name){
			case 'mode':
				$log->log('[varspage.class.php] Setting property `' . $name . '`', PEAR_LOG_DEBUG);
				if($value == self::RESERV_MODE || $value == self::CONSULT_MODE)
					$this->$name = $value;
				else
					$log->log('[varspage.class.php] Unable to set mode to `' . $value . '` (not one of known modes)', PEAR_LOG_WARNING);
				break;
			case 'enrsbypage':
				$log->log('[varspage.class.php] Setting property `' . $name . '`', PEAR_LOG_DEBUG);
				if($value == 'all' || preg_match('/[[:digit:]]/', $value) && $value > 0)
					$this->$name = (int)$value;
				else
					$log->log('[varspage.class.php] Value for `' . $name . '` should be a positive integer or \'all\' (' . $value . ' given)', PEAR_LOG_WARNING);
				break;
			case 'type':
			case 'director':
			case 'origin':
			case 'actor':
				$log->log('[varspage.class.php] Setting property `' . $name . '`', PEAR_LOG_DEBUG);
				if(is_array($value)){
					$filtered = array_filter($value);
					$unique = array_unique($filtered);
					if( count($unique) > 0 ) $this->$name = $unique;
				} else
					$this->$name = $value;
				break;
			case 'types_operator':
			case 'directors_operator':
			case 'origins_operator':
			case 'actors_operator':
				$log->log('[varspage.class.php] Setting property `' . $name . '`', PEAR_LOG_DEBUG);
				$this->$name = $value;
				break;
			case 'year':
			case 'duration':
				$log->log('[varspage.class.php] Setting property `' . $name . '`', PEAR_LOG_DEBUG);
				if(is_array($value)){
					$val = array(
						'from'	=>	$value[0],
						'to'	=>	$value[1],
					);
					$this->$name = $val;
				} else if($value == null)
					$this->$name = null;
				else
					$log->log('[varspage.class.php] Value for property `' . $name . '` should be an array', PEAR_LOG_DEBUG);
				break;
			default:
				$log->log('[varspage.class.php] Unable to set proprety `' . $name . '`', PEAR_LOG_WARNING);
				break;
		}
	}
}
?>