<?php
/*
 * mysql.class.php, 26 mai 2006
 * 
 * This file is part of videotheque.
 *
 * Copyright © 2005 Johan Cwiklinski
 *
 * File :               	mysql.class.php
 * Author's email :     	johan@x-tnd.be
 * Author's Website :   	http://x-tnd.be
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 */

require_once('MDB2.php');

/**
 * Database independent query interface
 *
 * This is a wrapper for the PEAR::MDB2 class
 *
 * @package    Vidéothèque
 * @author     Johan Cwiklinski <johan AT x-tnd DOT be>
 * @version    0.1
 * @link       http://videotheque.tuxfamily.org
 */
class VideoMdb2{
	private $db_dsnw;               // DSN for write operations
	private $db_dsnr;               // DSN for read operations
	private $db_connected = false;  // Already connected ?
	private $db_mode = '';          // Connection mode
	private $db_handle = 0;         // Connection handle
	private $db_error = false;
	private $db_error_msg = '';

	private $a_query_results = array('dummy');
	private $last_res_id = 0;

	private $persistent;
	private $dsn_array;
	private $db;

	/**
	* Default constructor
	*/
	function __construct($persistent=false){
		global $log;
		$this->persistent = $persistent;
		$dsn = _db_type.'://'._user.':'._password.'@'._host.'/'._db;
		$options = array(
			'persistent'	=>	$persistent,
			'debug'		=>	2,
			'portability'	=>	MDB2_PORTABILITY_ALL ^ MDB2_PORTABILITY_EMPTY_TO_NULL,
		);
		$this->dsn_array = MDB2::parseDSN($dsn);

		$this->db = MDB2::connect($dsn, $options);

		if (MDB2::isError($this->db)) {
			$log->log('MDB2 : no connexion (' . $this->db->getMessage() . ') - ' . $this->db->getDebugInfo(), PEAR_LOG_ALERT);
		}else
			$log->log('MDB2 : connected successfully', PEAR_LOG_INFO);

		$this->db->setFetchMode(MDB2_FETCHMODE_OBJECT);
	}

	/**
	* Dsiconnects properly from the database when this object is unset
	*/
	function __destruct(){
		$this->db->disconnect();
	}

	/**
	* Queries the database
	* @param query the query to execute
	*/
	public function query( $query ){
		global $log;
		$result = $this->db->query($query);
				// Vérification des erreurs
		if (MDB2::isError($result)) {
			$log->log('There were an error executing query ' . $query . '(' . $result->getMessage() . ') - ' . $result->getDebugInfo(), PEAR_LOG_ERR);
			return -1;
		}else{
			$log->log('Query successfull : ' . $query, PEAR_LOG_DEBUG);
			return $result;
		}
	}

	/**
	* Exectue a query on the database (ie. insert, update, delete)
	* ! This function seems to be absent from mysqli driver !
	* @param query the query to execute
	*/
	public function execute( $query ){
		global $log;
		$result = $this->db->exec($query);
				// Vérification des erreurs
		if (MDB2::isError($result)) {
			$log->log('There were an error executing query ' . $query . '(' . $result->getMessage() . ') - ' . $result->getDebugInfo(), PEAR_LOG_ERR);
			return -1;
		}else{
			$log->log('Query successfull : ' . $query, PEAR_LOG_DEBUG);
			return $result;
		}
	}

	public function getDb(){ return $this->db; }
}
?>